"""
    ZSS Attribute
    === =========

This object represents a CSS Attribute in a nice, editable, ZOPE object.
"""
__version__ = '4.0.1'

from Globals import HTMLFile, MessageDialog
from OFS import SimpleItem
from OFS import ObjectManager
from OFS import PropertyManager
from DocumentTemplate import DT_HTML

import string

import BrowserType
 
manage_addZSSAttrForm=HTMLFile('www/manage_addZSSAttribute', globals())

def manage_addZSSAttr(self, id, value='', Browsers=[], REQUEST=None):
    """ Add a ZSSAttr object """
    self._setObject(id, ZSSAttr(id, value, Browsers, REQUEST))
    if REQUEST is not None:
        if REQUEST.has_key('submit'):
            if REQUEST['submit']==' Add and Edit ':
                REQUEST.RESPONSE.redirect("%s/%s/manage_main" % (REQUEST['URL1'], obj.id))
                return ''
        REQUEST.RESPONSE.redirect("%s/manage_main" % REQUEST['URL1'])
    return ''

class ZSSAttr(	PropertyManager.PropertyManager,
                SimpleItem.SimpleItem,
                BrowserType.BrowserType):
    """ Representation of Cascading Style Sheet Attributes """
    meta_type    = 'ZSS Attribute'
    id           = 'ZSSAttr'
    icon         = 'misc_/ZStyleSheet/ZSSAttr'
    manage_options    = (
        PropertyManager.PropertyManager.manage_options
        +(
            {'label': 'View', 'action': 'preview',
             'help': ('ZStyleSheet', 'Preview.stx')},
            {'label': 'Dump', 'action': 'dump',
             'help': ('ZStyleSheet', 'Dump.stx')},
        )
        +SimpleItem.SimpleItem.manage_options
    )
    __ac_permissions__= (
        PropertyManager.PropertyManager.__ac_permissions__
        +SimpleItem.SimpleItem.__ac_permissions__
    )
    _properties=(
        {'id' : 'value', 'type': 'string', 'mode': 'w'},
        {'id' : 'Browsers', 'type' : 'multiple selection', 'mode': 'w', 'select_variable': 'BrowserList'},
    )

    def __init__(self, id, value='', Browsers=[], REQUEST=None):
        """ Initialise a ZSSAttr """
        self.id=id
        self.value=value
        if (not(Browsers)):
            Browsers=self.BrowserList()
        self.Browsers=Browsers

    def _dump(self, ignoreBrowsers=1, call=''):
        """ Add this attribute to a dump listing """
        return "/* Browsers=%s */\n\t%s: %s;" % (self.Browsers, self.getId(), DT_HTML.HTML(self.value, self.REQUEST, 'ZSSAttribute - %s' % self.getId()))

    def _value(self, ignoreBrowsers=0, call=''):
        """ Return the un-rendered DTML for this item """
        if self.BrowserName() in self.Browsers or ignoreBrowsers:
            return "<dtml-try>%s: %s;<dtml-except>/* ** WARNING ** Evaluation Failed - %s: %s*/</dtml-try>" % (self.getId(), self.value, self.getId(), DT_HTML.HTML(self.value, self.REQUEST))
        else:
            return "/* %s - Excluded for this browser */" % self.getId()

    def dump(self):
        """ Dump this attribute, showing the browser restrictions in comments. """
        dtml = '<dtml-var manage_page_header><dtml-var manage_tabs>'
        dtml = dtml + "<h1 align=center>Zope Style Sheet Attribute Dump</h1>"
        dtml = dtml + "<h2 align=center>%s</h2>" % self.getId()
        dtml = dtml + "<blockquote><pre>%s</pre></blockquote>" % self._dump()
        dtml = dtml + '<h5 align=center>Zope Style Sheet: <a href="http://www.zope.org/Members/haqa/ZStyleSheet">http://www.zope.org/Members/haqa/ZStyleSheet</a></h5>'
        dtml = dtml + "<dtml-var manage_page_footer>"
        obj = DT_HTML.HTML(dtml, self.REQUEST, 'ZSSAttribute - dump - %s' % self.getId())
        return obj(self.aq_inner, self.REQUEST)

    def preview(self):
        """ Render a human viewable version of this ZSSRule """
        dtml = "<dtml-var manage_page_header><dtml-var manage_tabs>\n"
        dtml = dtml + "<h1 align=center>Zope Style Sheet Attribute Preview</h1>"
        dtml = dtml + "<h2 align=center>%s</h2>" % self.title_and_id()
        dtml = dtml + "<blockquote><pre>%s</pre></blockquote>" % self._value()
        dtml = dtml + '<h5 align=center>Zope Style Sheet: <a href="http://www.zope.org/Members/haqa/ZStyleSheet">http://www.zope.org/Members/haqa/ZStyleSheet</a></h5>'
        dtml = dtml + "<dtml-var manage_page_footer>"
        obj = DT_HTML.HTML(dtml, self.REQUEST, 'ZSSAttribute - preview - %s' % self.title_and_id())
        return obj(self.aq_inner, self.REQUEST)

    def tag(self):
        """ Render this attribute """
        dtml = 'style="%s"' % (self._value(),)
        obj = DT_HTML.HTML(dtml, self.REQUEST, 'ZSSAttribute - %s' % self.getId())
        return obj(self.aq_inner, self.REQUEST)

    index_html = style = __call__ = __str__ = tag
